@@ -1,12 +1,3 @@
-import os
-import sys
-import py
-
-import json
-
-from devpi import log, cached_property
-from devpi.util import url as urlutil
-import posixpath
 
 def main(hub, args=None):
     hub.set_quiet()
@@ -17,12 +8,9 @@ def main(hub, args=None):
 
     current = hub.current
 
-    if path[0] != "/":
-        if not current.index:
-            hub.fatal("cannot use relative path without an active index")
-        url = urlutil.joinpath(current.get_index_url(), path)
-    else:
-        url = urlutil.joinpath(current.rooturl, path)
+    if path[0] != "/" and not current.index:
+        hub.fatal("cannot use relative path without an active index")
+    url = current.index_url.addpath(path)
     r = hub.http_api("get", url, quiet=True, check_version=False)
     if hub.args.verbose:
         hub.line("GET REQUEST sent to %s" % url)
