@@ -657,7 +657,8 @@ def test(parser):
 
     parser.add_argument("pkgspec", metavar="pkgspec", type=str,
         default=None, action="store", nargs=1,
-        help="package specification to download and test")
+        help="package specification in pip/setuptools requirement-syntax, "
+             "e.g. 'pytest' or 'pytest==2.4.2'")
 
 
 @subcommand("devpi.push")
@@ -721,6 +722,3 @@ def verify_reply_version(hub, reply):
                                      ",".join(acceptable_api_version)))
 
 
-
-if __name__ == "__main__":
-    main()
